@@ -292,6 +292,15 @@ TEST (EncodeMbAuxTest, WelsCalculateSingleCtr4x4_mmi) {
   FREE_MEMORY (iDctS);
 }
 #endif
+#ifdef HAVE_LASX
+TEST (EncodeMbAuxTest, WelsDctT4_lasx) {
+  TestDctT4 (WelsDctT4_lasx);
+}
+
+TEST (EncodeMbAuxTest, WelsDctFourT4_lasx) {
+  TestDctFourT4 (WelsDctFourT4_lasx);
+}
+#endif
 
 void copy (uint8_t* pDst, int32_t iDStride, uint8_t* pSrc, int32_t iSStride, int32_t iWidth, int32_t iHeight) {
   for (int i = 0; i < iHeight; i++)
@@ -571,6 +580,10 @@ TEST (EncodeMbAuxTest, WelsQuantFour4x4Max_mmi) {
 #endif //HAVE_MMI
 
 #ifdef HAVE_LSX
+TEST (EncodeMbAuxTest, WelsQuantFour4x4_lsx) {
+  if (WelsCPUFeatureDetect (0) & WELS_CPU_LSX)
+    TestWelsQuantFour4x4 (WelsQuantFour4x4_lsx);
+}
 TEST (EncodeMbAuxTest, WelsQuantFour4x4Max_lsx) {
   if (WelsCPUFeatureDetect (0) & WELS_CPU_LSX)
     TestWelsQuantFour4x4Max (WelsQuantFour4x4Max_lsx);
